@@ -1,6 +1,6 @@
 from sgraph.sgraph import SGraph
 from sgraph.selement import SElement
-from sgraph.selementmergedexception import SElementMergedException
+from sgraph.exceptions import SElementMergedException, ModelNotFoundException
 from sgraph.selementassociation import SElementAssociation
 from sgraph.modelapi import ModelApi
 from sgraph.metricsapi import MetricsApi
